#! /usr/bin/python
from table import Table

configuration_table = Table('configuration', [('ip', 'varchar', 'the ip address'),
                                              ('active', 'integer', '[bool] whether the configuration is the active one for the ip address'),
                                              ('text', 'integer', '[bool] text install or not (i.e. graphical)'),
                                              ('reboot', 'integer', '[bool] reboot at the end or not'),
                                              ('lilocheck', 'integer', '[bool] look for lilo before installing or not')
                                              ])

class Configuration:
    def __init__(self, ip):
        self.ip = ip
        '''Look up the configuratin by ip address and check the active flag.
        There should be only one active configuration per ip'''
        self.release = 'phoebe' ## %R
        self.release_appendix = '3' ## normally '': %A

        self.get_install_info()
        self.get_language_info()
        self.get_input_info()
        self.get_graphics_info()
        self.get_partition_info()
        self.get_authorization_info()
        self.get_bootloader_info()
        self.get_device_info()
        self.get_firewall_info()
        self.get_network_device_info()
        self.get_time_info()
        self.get_root_password()
        self.get_packages_info()
        self.get_pre_info()
        self.get_post_info()

        return

    def replace_strings(self, instr):
        outstr = instr.replace('%R', self.release)
        outstr = outstr.replace('%A', self.release)
        return outstr

    def get_install_info(self):
        '''Get information pertaining to the installation type and location
        boolean option:
          text
        boolean option:
          reboot
        boolean option:
          lilocheck

        choose one of:
          install
          upgrade

        choose one of:
          <None> (default)
          autostep (optional)
          interactive (optional)

        optional:
          driverdisk
        select one of
          cdrom
          harddrive --partition=<part> --dir=<dir>
          nfs --server=<server> --dir=<dir>
          url --url (http://<server>/<dir>)|(url --url ftp://<username>:<password>@<server>/<dir>)
        '''
        self.text = ''
        self.reboot = ''
        self.lilocheck = ''
        self.install = 'install'
        self.interactive = ''
        self.driverdisk = ''
        self.type = 'nfs'
        self.server = 'kickstart'
        self.dir = '/nfs/u3/%R/i386'
        return

    def get_install_string(self):
        '''Create install info string'''
        nl = '\n'
        _str = nl+self.install+nl
        _str += self.text
        _str += self.interactive
        _str += self.reboot
        _str += self.lilocheck
        _str += self.driverdisk

        server = self.replace_strings(self.server)
        dir = self.replace_strings(self.dir)
        if self.type == 'nfs':
            _str += 'nfs --server %s --dir %s' % (server, dir)+nl
        elif self.type == 'http':
            _str += 'url --url http://%s/%s' % (server, dir)+nl
        elif self.type == 'ftp':
            _str += 'url --url ftp://%s/%s' % (server, dir)+nl
        elif self.type == 'cdrom':
            _str += 'cdrom'+nl
        return _str

## DANGER
##    def get_partition_info(self):
##        '''\
##        clearpart (optional)
##        part or partition (required for installs, ignored for upgrades)
##        logvol (optional) [1]
##        volgroup (optional) [1]
##        raid (optional)
##        zerombr (optional)
##        '''
##        self.partition_info = []
##        self.partition_info.append('clearpart --all --drives=hda --initlabel')
##        self.partition_info.append('part / --fstype ext3 --size=1024 --grow')
##        self.partition_info.append('part swap --size=256 --grow --maxsize=512')


    def get_partition_string(self):
        '''Write partition info'''
        nl = '\n'
        _str = ''
        for p in self.partition_info:
            _str += p+nl
        return _str

    def get_language_info(self):
        '''\
        lang (required)
        langsupport (required)
        '''
        self.lang = 'en_US'
        self.defaultlang = 'en_US.UTF-8'
        self.langsupport = 'en_US.UTF-8 zh_HK.UTF-8 zh_CN.GB18030 zh_TW.Big5 en_US.UTF-8 fi_FI.UTF-8 fr_CA.UTF-8 fr_FR.UTF-8 ru_RU.UTF-8 es_MX.UTF-8 es_ES.UTF-8 es_US.UTF-8 sv_FI.UTF-8'
        return

    def get_language_string(self):
        _str = 'lang %s\n'%self.lang
        _str += 'langsupport --default %s %s\n' % (self.defaultlang, self.langsupport)
        return _str

    def get_input_info(self):
        self.keyboard = 'us'
        self.mouse = 'alpsps/2'
        self.mousedev = 'psaux'
        self.mouse_emul3 = 'yes'
        return

    def get_input_string(self):
        _str = 'keyboard %s\n' % self.keyboard
        _str += 'mouse %s' % self.mouse
        if self.mousedev:
            _str += ' --device %s' % self.mousedev
        if self.mouse_emul3:
            _str += ' --emulthree'
        _str += '\n'
        return _str

    def get_graphics_info(self):
        self.skipx = ''
        self.card = 'Trident Cyber 9388 (generic)'
        self.monitor = 'Generic Laptop Display Panel 1024x768'
        self.videoram = '2048'
        self.depth = '16'
        self.resolution = '1024x768'
        self.desktop = 'gnome'
        self.bootx = 'yes'
        return

    def get_graphics_string(self):
        if self.skipx:
            _str = 'skipx\n'
        else:
            _str = 'xconfig --card "%s" --monitor "%s"' % (self.card, self.monitor)
            if self.videoram:
                _str += ' --videoram %s' % self.videoram
            if self.depth:
                _str += ' --depth %s' % self.depth
            if self.resolution:
                _str += ' --resolution %s' % self.resolution
            if self.desktop:
                _str += ' --defaultdesktop %s' % self.desktop
            if self.bootx:
                _str += ' --startxonboot'
            _str += '\n'
        return _str

    def get_authorization_info(self):
        return

    def get_authorization_string(self):
        return 'auth --useshadow --enablemd5\n'

    def get_bootloader_info(self):
        return

    def get_bootloader_string(self):
<snip>


    def get_device_info(self):
        return

    def get_device_string(self):
        return ''

    def get_firewall_info(self):
        return

    def get_firewall_string(self):
        return 'firewall --disabled\n'

    def get_network_device_info(self):
        return

    def get_network_device_string(self):
        return 'network --bootproto dhcp\n'

    def get_time_info(self):
        return

    def get_time_string(self):
        return 'timezone America/Denver\n'

    def get_root_password(self):
        return

    def get_root_password_string(self):
<snip>


    def get_packages_info(self):
        self.deps = 'resolve'

        self.packages = [
            '@ Administration Tools',
            '@ Authoring and Publishing',
            '@ Development Tools',
            '@ Dialup Networking Support',
            '@ Editors',
            '@ Engineering and Scientific',
            '@ GNOME Desktop Environment',
            '@ Games and Entertainment',
            '@ Graphical Internet',
            '@ Graphics',
            '@ Kernel Development',
            '@ Mail Server',
            '@ Network Servers',
            '@ Office/Productivity',
            '@ Printing Support',
            '@ SQL Database Server',
            '@ Server Configuration Tools',
            '@ Sound and Video',
            '@ System Tools',
            '@ Text-based Internet',
            '@ Web Server',
            '@ Windows File Server',
            '@ X Window System',
            'jed',
            'dhcp',
            'galeon',
            'unixODBC-devel',
            'rpmdb-redhat',
            'sndconfig'
            ]
        return

    def get_packages_string(self):
        _str = '%packages'
        if self.deps:
            _str += ' --%sdeps' % self.deps
        _str += '\n'

        for p in self.packages:
            _str += p+'\n'
        return _str

    def get_pre_info(self):
        self.pre_interpreter = ''
        self.pre_script = 'echo "=========================== Start of %pre ============================"\n'+ \
                          '# == Expose the files on kickstart to %include\n' + \
<snip>
                          'echo "============================ End of %pre ============================="\n'
        return

    def get_pre_string(self):
        _str = '%pre'
        if self.pre_interpreter:
            _str += ' --interpreter %s' % self.pre_interpreter
        _str += '\n'

        _str += self.pre_script
        return _str

    def get_post_info(self):
        self.post_interpreter = ''
        self.post_script = 'echo "=========================== Start of %post ============================"\n' + \
                           'mkdir -p /nfs/kickstart\n' + \
<snip>
                           '\n' + \
                           '/nfs/kickstart/.scripts/post.sh >> /root/post.log 2>&1\n' + \
                           '/nfs/kickstart/.scripts/mza/mza-post.sh >> /root/mza-post.log 2>&1\n' + \
                           '/nfs/kickstart/.scripts/mza/phoebe-post.sh >> /root/mza-phoebe-post.log 2>&1\n' + \
                           '/nfs/kickstart/.scripts/mza/aspen/phoebe-aspen.sh >> /root/mza-phoebe-aspen-post.log 2>&1\n' + \
                           '\n' + \
                           'echo "============================ End of %post ============================="\n'
        return

    def get_post_string(self):
        _str = '%post'
        if self.post_interpreter:
            _str += ' --interpreter %s' % self.post_interpreter
        _str += '\n'

        _str += self.post_script
        return _str

    def get_kickstart(self):
        _str = '## %s kickstart configuration for %s' % (self.release, self.ip)
        _str += self.get_install_string()
        _str += self.get_language_string()
        _str += self.get_input_string()
        _str += self.get_graphics_string()
        _str += self.get_partition_string()
        _str += self.get_authorization_string()
        _str += self.get_bootloader_string()
        _str += self.get_device_string()
        _str += self.get_firewall_string()
        _str += self.get_network_device_string()
        _str += self.get_time_string()
        _str += self.get_root_password_string()
        _str += self.get_packages_string()
        _str += self.get_pre_string()
        _str += self.get_post_string()

        return _str 

if __name__ == '__main__':
    exit(0)
